@@ -12,15 +12,14 @@ import os, requests
 import pwd
 import datetime
 import pkg_resources
-import sys
+import sys, time
 
 KEYLEN = 32
 DEFAULT_HOST = "v2.decipherinc.com"
 
 def date_to_isoformat(o):
     # convert local timestap to iso8601 format
-    # apparently this is how to do it without requiring the pytz module installed
-    return datetime.datetime.utcfromtimestamp(int(o.strftime("%s"))).isoformat() + 'Z'
+    time.strftime("%FT%TZ", time.gmtime(int(o.strftime("%s"))))
 
 class JSONEncoder(json.JSONEncoder):
     def default(self, o):
